@@ -6,6 +6,9 @@ use Carp;
 use base 'Exporter';
 use Dancer::Config 'setting';
 use Dancer::Hook;
+use Dancer::Factory::Hook;
+use Dancer::Exception qw(:all);
+
 use base 'Exporter';
 use vars qw(@EXPORT);
 
@@ -14,6 +17,8 @@ use vars qw(@EXPORT);
   register
   register_plugin
   plugin_setting
+  register_hook
+  execute_hooks
 );
 
 sub register($&);
@@ -29,19 +34,33 @@ sub plugin_setting {
     return setting('plugins')->{$plugin_name} ||= {};
 }
 
+sub register_hook {
+    Dancer::Factory::Hook->instance->install_hooks(@_);
+}
+
+sub execute_hooks {
+    Dancer::Factory::Hook->instance->execute_hooks(@_);
+}
+
 sub register($&) {
     my ($keyword, $code) = @_;
     my $plugin_name = caller();
 
     $keyword =~ /^[a-zA-Z_]+[a-zA-Z0-9_]*$/
-      or croak "You can't use '$keyword', it is an invalid name (it should match ^[a-zA-Z_]+[a-zA-Z0-9_]*$ )";
+      or raise core_plugin => "You can't use '$keyword', it is an invalid name"
+        . " (it should match ^[a-zA-Z_]+[a-zA-Z0-9_]*$ )";
 
-    if (grep { $_ eq $keyword } map { s/^(?:\$|%|&|@|\*)//; $_ } (@Dancer::EXPORT, @Dancer::EXPORT_OK)) {
-        croak "You can't use '$keyword', this is a reserved keyword";
+    if (
+        grep { $_ eq $keyword } 
+        map  { s/^(?:\$|%|&|@|\*)//; $_ } 
+        (@Dancer::EXPORT, @Dancer::EXPORT_OK)
+    ) {
+        raise core_plugin => "You can't use '$keyword', this is a reserved keyword";
     }
     while (my ($plugin, $keywords) = each %$_keywords) {
         if (grep { $_->[0] eq $keyword } @$keywords) {
-            croak "You can't use $keyword, this is a keyword reserved by $plugin";
+            raise core_plugin => "You can't use $keyword, "
+                . "this is a keyword reserved by $plugin";
         }
     }
 
@@ -149,15 +168,38 @@ module).
 
 A Dancer plugin inherits from Dancer::Plugin and Exporter transparently.
 
+=item B<register_hook>
+
+Allows a plugin to delcare a list of supported hooks. Any hook declared like so
+can be executed by the plugin with C<execute_hooks>.
+
+    register_hook 'foo'; 
+    register_hook 'foo', 'bar', 'baz'; 
+
+=item B<execute_hooks>
+
+Allows a plugin to execute the hooks attached at the given position
+
+    execute_hooks 'some_hook';
+
+The hook must have been registered by the plugin first, with C<register_hook>.
+
 =item B<plugin_setting>
 
-Configuration for plugin should be structured like this in the config.yaml of the application:
+Configuration for plugin should be structured like this in the config.yml of
+the application:
 
   plugins:
     plugin_name:
       key: value
 
-If plugin_setting is called inside a plugin, the appropriate configuration will be returned. The plugin_name should be the name of the package, or, if the plugin name is under the B<Dancer::Plugin::> namespace, the remaining part of the plugin name. Enclose the remaining part in quotes if it contains ::, e.g. for B<Dancer::Plugin::Foo::Bar>, use:
+If C<plugin_setting> is called inside a plugin, the appropriate configuration 
+will be returned. The C<plugin_name> should be the name of the package, or, 
+if the plugin name is under the B<Dancer::Plugin::> namespace (which is
+recommended), the remaining part of the plugin name. 
+
+Enclose the remaining part in quotes if it contains ::, e.g.
+for B<Dancer::Plugin::Foo::Bar>, use:
 
   plugins:
     "Foo::Bar":
