@@ -6,13 +6,9 @@ register_hook 'start_hookee', 'stop_hookee';
 register_hook 'third_hook';
 
 register some_keyword => sub {
-    execute_hook('start_hookee');
+    execute_hooks('start_hookee');
 };
 
-register some_other => sub {
-    execute_hook('third_hook');
-};
-
-register_plugin for_versions => [2];
+register_plugin for_versions => [ 2 ];
 
 1;
